==> haskell-free-5.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 5.1
id: free-5.1-A2R1m0ugIQw8vGOik0WLGU
key: free-5.1-A2R1m0ugIQw8vGOik0WLGU
license: BSD-3-Clause
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
abi: 7662838d662d7f08e53fab5bc655a913
exposed: True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
hidden-modules: Data.Functor.Classes.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/free-5.1
hs-libraries: HSfree-5.1-A2R1m0ugIQw8vGOik0WLGU
includes:
    free-common.h
depends:
    base-4.11.1.0 comonad-5.0.4-1EfSpa6AA5U3LtobVlqSjD
    distributive-0.6-B8BDdSVNDKTHDH1BzGjzru mtl-2.2.2
    profunctors-5.3-IgECUkHj2LhJdroAs5SPJF
    semigroupoids-5.3.1-GSqAErYrQXPJ6o7TiDrxrJ transformers-0.5.5.0
    transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ
    template-haskell-2.13.0.0 exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
    containers-0.5.11.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             comonad-5.0.4-1EfSpa6AA5U3LtobVlqSjD=bee891a03b83d11cad862c41f78926bb
             distributive-0.6-B8BDdSVNDKTHDH1BzGjzru=a5537fed2457e809aa6ef5013a4c417b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             profunctors-5.3-IgECUkHj2LhJdroAs5SPJF=27920699c0331e1500e4159f354cda5a
             semigroupoids-5.3.1-GSqAErYrQXPJ6o7TiDrxrJ=32760aa5f22be0ff83685760532ed5ea
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ=ff843a556414f5766b414ccfa8c6dff6
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-5.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 5.1
id: free-5.1-G3DMlAEaYnj3OWnUWyYXAm
key: free-5.1-G3DMlAEaYnj3OWnUWyYXAm
license: BSD-3-Clause
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
abi: cfed53672364575fb0476d3ddf3745d0
exposed: True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
hidden-modules: Data.Functor.Classes.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/free-5.1
hs-libraries: HSfree-5.1-G3DMlAEaYnj3OWnUWyYXAm
includes:
    free-common.h
depends:
    base-4.11.1.0 comonad-5.0.4-3a3eb7VXjyTBj8gF3eWZTj
    distributive-0.6-Ky8WgEWYWI7J4wvZ2KGZlo mtl-2.2.2
    profunctors-5.3-4704WQ9ngLC3F8GtGRMbw8
    semigroupoids-5.3.1-CO2ReMHLhJg164k5JCnsOd transformers-0.5.5.0
    transformers-base-0.4.5.2-CJkbYH4N4LV8hMEohn0j3d
    template-haskell-2.13.0.0 exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
    containers-0.5.11.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             comonad-5.0.4-3a3eb7VXjyTBj8gF3eWZTj=8fdc4dc9241d421d8cd18312b441b5e8
             distributive-0.6-Ky8WgEWYWI7J4wvZ2KGZlo=ee0b0e0f38c0fe1e88dea6083866fe68
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             profunctors-5.3-4704WQ9ngLC3F8GtGRMbw8=0fbd1f79d0d70fa90203563792d0ce68
             semigroupoids-5.3.1-CO2ReMHLhJg164k5JCnsOd=18efd8d4738e022c6267648b1a74d1fc
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-CJkbYH4N4LV8hMEohn0j3d=85e83aa98f31119a75b463e70412c07f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
